@@ -1,10 +1,10 @@
 /*
  *
- * Wizard Monuter - 1.1
+ * Wizard Monuter - 1.4
  *
  * @author		b0unc3
  * @date		31/10/2007
- * @last update		05/03/2007
+ * @last update		03/07/2009
  * @license		BSD
  *
  *
@@ -38,6 +38,9 @@
 #define MNT_PROC		"/proc/mounts"
 #define PROFILE_DIR		"/home/user/.wm/"
 #define WM_MOUNT_DIR		"/home/user/MyDocs/Remote_Filesystem/"
+/* as suggest by Bobbie`s pathc */
+#define USER_ID			29999
+#define GROUP_ID		29999
 
 
 enum
@@ -217,7 +220,7 @@ gboolean mount ( gchar *server, gchar *remote_dir , int type, gchar *user, gchar
 	if ( type == 1 ) {
 		mnt = g_strdup_printf("/usr/bin/sudo /bin/mount -t nfs %s:\"%s\" %s", server,remote_dir, dir);
 	} else {
-		mnt = g_strdup_printf("/usr/bin/sudo /sbin/mount.cifs \"//%s/%s\" \"%s\" -o username=\"%s\",password=\"%s\"\n",server,remote_dir,dir,user,pwd);
+		mnt = g_strdup_printf("/usr/bin/sudo /sbin/mount.cifs \"//%s/%s\" \"%s\" -o username=\"%s\",password=\"%s\",uid=%d,gid=%d\n",server,remote_dir,dir,user,pwd,USER_ID,GROUP_ID);
 	}
 	if ( g_spawn_command_line_sync(mnt,&out,&err,&exit,&error) ) {
 		if ( strlen(err) < 2 ) {
